Crate set_of

Crate set_of 

I consent to the transfer of this crate to the first person who asks help@crates.io for it.

Macros

error_set

Traits

CoerceResult
ConsumeDebugtracing or log or defmt or context_stub
For logging a Result’s Err in the Debug format when an Err is encountered.
ConsumeDisplaytracing or log or defmt or context_stub
For logging a Result’s Err in the Display format when an Err is encountered.
OptionContexttracing or log or defmt or context_stub
For logging when a None is encountered.
ResultContexttracing or log or defmt or context_stub
For logging a Result when an Err is encountered.