I consent to the transfer of this crate to the first person who asks help@crates.io for it.
Macros
Traits
- Coerce
Result - Consume
Debug tracingorlogordefmtorcontext_stub - For logging a Result’s Err in the Debug format when an Err is encountered.
- Consume
Display tracingorlogordefmtorcontext_stub - For logging a Result’s Err in the Display format when an Err is encountered.
- Option
Context tracingorlogordefmtorcontext_stub - For logging when a None is encountered.
- Result
Context tracingorlogordefmtorcontext_stub - For logging a Result when an Err is encountered.